@@ -1,20 +1,16 @@
 from django.db import models
 from django.utils.translation import gettext_lazy as _
 
-from generic_permissions.models import PermissionModelMixin, VisibilityModelMixin
-
 
 class BaseModel(models.Model):
-    """
-    Base for test models that sets app_label, so they play nicely.
-    """
+    """Base for test models that sets app_label, so they play nicely."""
 
     class Meta:
         app_label = "tests"
         abstract = True
 
 
-class Model1(PermissionModelMixin, VisibilityModelMixin, BaseModel):
+class Model1(BaseModel):
     text = models.CharField(
         max_length=100,
         verbose_name=_("Text comes here"),
@@ -22,7 +18,7 @@ class Model1(PermissionModelMixin, VisibilityModelMixin, BaseModel):
     )
 
 
-class Model2(PermissionModelMixin, VisibilityModelMixin, BaseModel):
+class Model2(BaseModel):
     text = models.CharField(
         max_length=100,
         verbose_name=_("Text comes here"),
